\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{solmu}[1999/09/06 Solmu]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\PassOptionsToPackage{draft,final}{graphicx}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\LoadClass[a4paper,twoside]{article}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Kieleen ja merkistn liittyvt paketit
\RequirePackage[finnish]{babel}
\RequirePackage[latin1]{inputenc}
\RequirePackage[T1]{fontenc}

% Apupaketti laskemista varten
\RequirePackage{calc}

% Paljon matematiikkaan liittyv
\RequirePackage[intlimits]{amsmath}
\RequirePackage{amsfonts}

% Xy-pic, "matemaattisia" kuvia varten
%\RequirePackage[all]{xy}
% Tm vie paljon TeXin muistia! Parempi tehd kuvista erikseen 
% epsi ja kytt sitten graphicxia, tai sitten ottaa xy:st vain
% se mit tarvitaan.

% Muulla tavalla piirrettyj kuvia varten
\RequirePackage[final]{graphicx}

% Sivun muotoiluun
\RequirePackage{vpage}
\RequirePackage{fancyheadings}

% Erilaisia luetteloja
\RequirePackage{enumerate}

% Ulkonkpaketteja: monipalstainen teksti, tekstin
% vistmt kuvat, tekstin sovittaminen annettuun kokoon,
% taulukon muotoilu
\RequirePackage{multicol}
\RequirePackage{picinpar}   % oli ennen {floatflt}
\RequirePackage{textfit}
\RequirePackage{array}

% WWW-linkkien muodostamiseen
%\RequirePackage[colorlinks,urlcolor=blue]{hyperref}

% Kehystetty minipage (LaTeX Companion, A.2.4)
\newsavebox{\fminibox}
\newlength{\fminilength}
\newenvironment{fminipage}[1][\linewidth]
 {\setlength{\fminilength}{#1-2\fboxsep-2\fboxrule}%
  \begin{lrbox}{\fminibox}\begin{minipage}{\fminilength}}
 {\end{minipage}\end{lrbox}\noindent\fbox{\usebox{\fminibox}}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Muotoillaan sivu

\setlength{\hoffset}{-1in}
\setlength{\voffset}{-1in}
\setpapersize{Afour}
\setmargins{2cm}{1.5cm}{17cm}{24.5cm}{12pt}{18pt}{0pt}{0pt}
% leftmargin, topmargin, textwidth, textheight,
% headheight, headsep, footheight, footskip

% Ala- ja ylreunat

\pagestyle{fancy}
\lhead[\small\arabic{page}]{\small Solmu}
\rhead[\small Solmu]{\small\arabic{page}}
\chead[]{}
\lfoot[]{}
\rfoot[]{}
\cfoot[]{}
%\setlength{\headrulewidth}{0pt}

% Palstojen vli
\setlength{\columnseprule}{\headrulewidth}
\addtolength{\columnsep}{1mm}

% Joitain matematiikkamakroja

% Matti Lehtisen kyttmt -- huomaa, ett \( ja \) ovat LaTeXin komentoja!
\def\as{^{\circ}}
\def\({\left(}
\def\){\right)}

% Kerkko Luoston kyttmt
\newcommand{\NN}{\mathbb{N}}
\newcommand{\osaj}{\subset}

\makeatletter
\def\joukko#1%
    {\relax\ifmmode\joukk@#1\rel@x!\rel@x\rel@x
           \else$\joukk@#1\rel@x!\rel@x\rel@x$\fi}
\let\rel@x\relax
\def\joukk@ #1!#2\rel@x #3\rel@x
    {\if!#3\{\,#1\mid#2\,\}\else
     \{#1\}\fi}
\makeatother


% Komentoja

% lainaus-ymprist, pasiassa lehdistkatsauksiin

\makeatletter
\newenvironment{lainaus}
               {\list{}{\itemindent 8em \leftmargin 0pt \rightmargin 0pt}
                \slshape%
                \item\relax}
               {\endlist}

% suora puolilainausmerkki
\font\plmfont=cmtt10
\def\plm{{\plmfont\symbol{'015}}}

% Luvut, aliluvut jne:
% \section = artikkeli

\renewcommand\section{\@startsection {section}{1}{\z@}%
                                     {-3.5ex \@plus -1ex \@minus -.2ex}%
                                     {3.0ex \@plus.5ex \@minus .5ex}%
                                     {\normalfont\Huge\bfseries\raggedright}}

\renewcommand\thesection{\relax}

\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalfont\Large\bfseries}}

\renewcommand\thesubsection{\@arabic\c@subsection}

\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalfont\large\bfseries}}  



\makeatother


\newlength{\palstanleveys}
\setlength{\palstanleveys}{(\textwidth-\columnsep)/2}

\newcommand{\aihekuva}[1]{%
  \raisebox{1cm}[0pt][0pt]{\includegraphics*{#1}}%
  \vspace*{-1cm}%
}
\newcommand{\artikkeli}[1]{%
  \section*{#1}%
  \addcontentsline{toc}{section}{#1}%
}

\newcommand{\kirjoittanut}[1]{%
  \nopagebreak%
  \begin{flushleft}%
    #1
  \end{flushleft}}

\newcommand{\linkki}[2]{#1\footnote{\texttt{#2}}}
\newcommand{\anfangi}[1]{\bigdrop{0pt}{2}{ecrm24}{#1}}
\renewcommand{\emph}[1]{\textsl{#1\/}} % korostus

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
